from enum import Enum
from typing import Any, Optional


class CaseInsensitiveEnum(str, Enum):
    @classmethod
    def _missing_(cls, value: Any) -> Optional[str]:
        if isinstance(value, str):
            value = value.lower()
            for member in cls:
                if member.lower() == value:
                    return member
        return None



def test_import() -> None:
    from nuclia_models.common.client import ClientType  # noqa: F401
    from nuclia_models.common.pagination import Pagination  # noqa: F401
    from nuclia_models.common.user import UserType  # noqa: F401
    from nuclia_models.events.activity_logs import ActivityLogs  # noqa: F401
